@@ -1,7 +1,7 @@
 ## Xmgrace.pm is a sub-module of Graph.pm. It has all the subroutines 
 ## needed for the gnuplot part of the package.
 ##
-## $Id: Xmgrace.pm,v 1.36 2015/10/05 20:35:33 rkoga Exp $ $Name: Chart-Graph-Release-3-3-1 $
+## $Id: Xmgrace.pm,v 1.32 2006/06/02 23:33:07 emile Exp $ $Name:  $
 ##
 ## This software product is developed by Esmond Lee and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -52,12 +52,12 @@ use Chart::Graph::Xmgrace::Graph_Presentation_Type;
 use Chart::Graph::Xmgrace::Dataset;
 use FileHandle;
 
-$cvs_Id = '$Id: Xmgrace.pm,v 1.36 2015/10/05 20:35:33 rkoga Exp $';
-$cvs_Author = '$Author: rkoga $';
-$cvs_Name = '$Name: Chart-Graph-Release-3-3-1 $';
-$cvs_Revision = '$Revision: 1.36 $';
+$cvs_Id = '$Id: Xmgrace.pm,v 1.32 2006/06/02 23:33:07 emile Exp $';
+$cvs_Author = '$Author: emile $';
+$cvs_Name = '$Name:  $';
+$cvs_Revision = '$Revision: 1.32 $';
 
-$VERSION = 3.3.1;
+$VERSION = 3.1;
 
 use strict;
 
@@ -1084,7 +1084,7 @@ sub _set_title ($ ) {
 ####################################################################
 #
 # The following functions are used to map an option value from 
-# prose to its corresponding number value which grace understands
+# prose to it's corresponding number value which grace understands
 # Note: these routines are not used in the current version. the user
 #       must use numbers (NOT prose) for now.
 #
@@ -1372,7 +1372,7 @@ directing in Xmgrace.
  |                   |    example                     |                       |
  +-------------------+--------------------------------+-----------------------+
 
-In Xmgrace each set of data has its own options.  Because Xmgrace is
+In Xmgrace each set of data has it's own options.  Because Xmgrace is
 so complex.  a sub-hash of options is needed for all the options
 associated with each data set.  For that reason, only a few data
 options are noted here.
@@ -1684,7 +1684,7 @@ last plot is a bar graph.
        );
 
 =for html
-<p><center><img src="xmgrace1.png"></center></p>
+<p><center><img src="http://www.caida.org/tools/utilities/graphing/xmgrace1.png"></center></p>
 <p><center><em>xmgrace1.png</em></center></p>
 
 =head2 NON-STACKING REGIONS
@@ -1716,7 +1716,7 @@ data.)
 	 );
 
 =for html
-<p><center><img src="xmgrace2.png"></center></p>
+<p><center><img src="http://www.caida.org/tools/utilities/graphing/xmgrace2.png"></center></p>
 <p><center><em>xmgrace2.png</em></center></p>
 
 
@@ -1927,7 +1927,7 @@ Data-Dumper.
 
 
 =for html
-<p><center><img src="xmgrace3.png"></center></p>
+<p><center><img src="http://www.caida.org/tools/utilities/graphing/xmgrace3.png"></center></p>
 <p><center><em>xmgrace3.png</em></center></p>
 
 
@@ -1941,7 +1941,7 @@ For more information on Xmgrace, please see the Xmgrace web page:
 
 =head1 CONTACT
 
-Send email to graph-dev@caida.org if you have problems, questions,
+Send email to graph-dev@caida.org is you have problems, questions,
 or comments. To subscribe to the mailing list send mail to
 graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
@@ -1951,7 +1951,7 @@ graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
 =head1 SEE ALSO
 
- xmgrace(1)
+ xmgrace(1).
 
 
 =cut
