@@ -1,7 +1,7 @@
 ## Xrt3d.pm is a sub-module of Graph.pm. It has all the subroutines 
 ## needed for the Xrt3d part of the package.
 ##
-## $Id: Xrt3d.pm,v 1.33 2015/10/06 06:17:14 rkoga Exp $ $Name: Chart-Graph-Release-3-3-1 $
+## $Id: Xrt3d.pm,v 1.28 2006/06/02 23:33:07 emile Exp $ $Name:  $
 ##
 ## This software product is developed by Michael Young and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -49,12 +49,12 @@ use Carp;			# for carp() and croak()
 use Chart::Graph::Utils qw(:UTILS);	# get global subs and variables
 use Chart::Graph::XrtUtils qw(:UTILS);
 
-$cvs_Id = '$Id: Xrt3d.pm,v 1.33 2015/10/06 06:17:14 rkoga Exp $';
-$cvs_Author = '$Author: rkoga $';
-$cvs_Name = '$Name: Chart-Graph-Release-3-3-1 $';
-$cvs_Revision = '$Revision: 1.33 $';
+$cvs_Id = '$Id: Xrt3d.pm,v 1.28 2006/06/02 23:33:07 emile Exp $';
+$cvs_Author = '$Author: emile $';
+$cvs_Name = '$Name:  $';
+$cvs_Revision = '$Revision: 1.28 $';
 
-$VERSION = 3.3.1;
+$VERSION = 3.1;
 
 use strict;
 
@@ -417,12 +417,12 @@ Chart::Graph::Xrt3d
 This module is unmaintained, it worked with Sitraka's XRT, and hasn't been
 tested against newer versions.
 
-Sitraka (now Dell) makes a number of graphics packages for UNIX systems.  XRT is
+Sitraka (now Quest) makes a number of graphics packages for UNIX systems.  XRT is
 a Motif-based commercial software product that has been adapted by
 CAIDA using a combination of C drivers and Perl function I<xrt3d()>.
 The Perl function I<xrt3d()> provides access to the three dimensional
 graphing capabilities of XRT from Perl.  To access the two dimensional
-graphing using XRT, use I<xrt2d()> which is also supplied in the
+graphing using XRT, use I<xrt2d()> also supplied in the
 I<Chart::Graph> package.
 
 =head1 ARGUMENTS
@@ -473,7 +473,7 @@ converter packages: I<Imagemagick> and I<Netpbm>.
 If you need to install a converter package,I<Imagemagick> 
 I<http://www.imagemagick.org/> is probably preferable
 simply for its comparatively simplicity.  It uses one program
-I<convert> for all of its conversion needs, so it is easy to manage
+I<convert> for all of it's conversion needs, so it is easy to manage
 and simple for Chart::Graph to use.  Many UNIX systems come with some
 collection of the I<Netpbm> utilities already installed, thus users
 may be able to start using Chart::Graph without adding any additional
@@ -527,7 +527,7 @@ provided.
 			   ["70", "45", "10", "5", "4", "3"]])
 
 =for html
-<p><center><img src="xrt3d-1.jpg"></center></p>
+<p><center><img src="http://www.caida.org/tools/utilities/graphing/xrt3d-1.jpg"></center></p>
 <p><center><em>xrt3d-1.jpg</em></center></p>
 
 =head2 EXAMPLE: EARLY GROWTH OF THE INTERNET
@@ -568,12 +568,12 @@ of the newest graphics formats the PNG format: F<xrt3d-2.png>.
         );
 
 =for html
-<p><center><img src="xrt3d-2.png"></center></p>
+<p><center><img src="http://www.caida.org/tools/utilities/graphing/xrt3d-2.png"></center></p>
 <p><center><em>xrt3d-2.png</em></center></p>
 
 =head2 EXAMPLE: USING A DATA FILE FOR INPUT
 
-The next example uses a file instead of an array for its data source.
+The next example uses a file instead of a array for it's data source.
 The file is listed below the Perl code.
 
  #make sure to include Chart::Graph
@@ -592,12 +592,12 @@ The file is listed below the Perl code.
 
 The data file used in the above example is as follows.
 
- 10 15 23 10
- 4  13 35 45
+ 10 15 23  10
+ 4 13 35 45
  29 15 64 24
 
 =for html
-<p><center><img src="xrt3d-3.gif"></center></p>
+<p><center><img src="http://www.caida.org/tools/utilities/graphing/xrt3d-3.gif"></center></p>
 <p><center><em>xrt3d-3.gif</em></center></p>
 
 
@@ -605,11 +605,11 @@ The data file used in the above example is as follows.
 
 For more information on XRT:
 
- http://software.dell.com/products/xrt-pds/
+ http://www.quest.com/xrt_pds/
 
 =head1 CONTACT
 
-Send email to graph-dev@caida.org if you have problems, questions,
+Send email to graph-dev@caida.org is you have problems, questions,
 or comments. To subscribe to the mailing list send mail to
 graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
